@@ -62,10 +62,12 @@ class TwoStageFallbackPolicy(FallbackPolicy):
         fallback_core_action_name: Text = ACTION_DEFAULT_FALLBACK_NAME,
         fallback_nlu_action_name: Text = ACTION_DEFAULT_FALLBACK_NAME,
         deny_suggestion_intent_name: Text = USER_INTENT_OUT_OF_SCOPE,
+        **kwargs: Any,
     ) -> None:
         """Create a new Two-stage Fallback policy.
 
         Args:
+            priority: The fallback policy priority.
             nlu_threshold: minimum threshold for NLU confidence.
                 If intent prediction confidence is lower than this,
                 predict fallback action with confidence 1.0.
@@ -88,6 +90,7 @@ class TwoStageFallbackPolicy(FallbackPolicy):
             ambiguity_threshold,
             core_threshold,
             fallback_core_action_name,
+            **kwargs,
         )
 
         self.fallback_nlu_action_name = fallback_nlu_action_name
