@@ -20,10 +20,11 @@ from rasa.shared.nlu.training_data.formats.readerwriter import (
     TrainingDataWriter,
 )
 import rasa.shared.utils.io
-
+import rasa.shared.nlu.training_data.util
 from rasa.shared.nlu.training_data.training_data import TrainingData
 from rasa.shared.nlu.training_data.message import Message
 
+
 logger = logging.getLogger(__name__)
 
 KEY_NLU = "nlu"
@@ -484,8 +485,15 @@ class RasaYAMLWriter(TrainingDataWriter):
             if intent_metadata:
                 intent[KEY_METADATA] = intent_metadata
 
-            render_as_objects = any(KEY_METADATA in ex for ex in converted)
-            if render_as_objects:
+            examples_have_metadata = any(KEY_METADATA in ex for ex in converted)
+            example_texts_have_escape_chars = any(
+                rasa.shared.nlu.training_data.util.has_string_escape_chars(
+                    ex.get(KEY_INTENT_TEXT, "")
+                )
+                for ex in converted
+            )
+
+            if examples_have_metadata or example_texts_have_escape_chars:
                 rendered = RasaYAMLWriter._render_training_examples_as_objects(
                     converted
                 )
@@ -541,9 +549,7 @@ class RasaYAMLWriter(TrainingDataWriter):
 
         def render(example: Dict) -> Dict:
             text = example[KEY_INTENT_TEXT]
-            example[KEY_INTENT_TEXT] = LiteralScalarString(
-                TrainingDataWriter.generate_string_item(text)
-            )
+            example[KEY_INTENT_TEXT] = LiteralScalarString(text + "\n")
             return example
 
         return [render(ex) for ex in examples]
